@@ -109,16 +109,19 @@ sub asfasta {
     # Update comment
     my ($self) = @_;
     my $space = length($self->{comment}) > 0 ? " " : "";
-    return ">" . $self->{name} . $space . $self->{comment} . "\n" . $self->{seq} . "\n";
+    my $name  = $self->{name} // "sequence";
+    my $comment = length($self->{comment}) > 0 ? " " . $self->{comment} : "";
+    return ">" . $name . $comment . "\n" . $self->{seq} . "\n";
 }
 
 
 sub asfastq {
     # Update comment
     my ($self) = @_;
-    my $space = length($self->{comment}) > 0 ? " " : "";
+    my $name  = $self->{name} // "sequence";
+    my $comment = length($self->{comment}) > 0 ? " " . $self->{comment} : "";
     my $quality = defined $self->{qual} ? " " . $self->{qual} : "I" x length($self->{seq});
-    return "@" . $self->{name} . $space . $self->{comment} . "\n" . $self->{seq} . "\n+\n" . $quality;
+    return "@" . $name . $comment . "\n" . $self->{seq} . "\n+\n" . $quality;
 }
 
 1;
@@ -135,7 +138,7 @@ FASTX::Seq - A class for representing a sequence for FASTX::Reader
 
 =head1 VERSION
 
-version 1.4.1
+version 1.5.0
 
 =head1 SYNOPSIS
 
